==> aksharamukha-1.6.8.tar.gz: aksharamukha-1.6.8/aksharamukha/ScriptMap/EastIndic/Javanese.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\uA984',
            '\uA984\uA9B4',
            '\uA986',
            '\uA987',
            '\uA988',
            '\uA988\uA9B4',
            '\uA989',
            '\uA989\uA9B4',
            '\uA98A',
            '\uA98B',
            '\uA98C',
            '\uA98D',
            '\uA98E',
            '\uA98E\uA9B4',
            ]

SouthVowelMap = [
                '\uA98C\u02BD',
                '\uA98E\u02BD',
                ]

ModernVowelMap = [
                 '\uA984\uA9BC',
                 '\uA984\uA9B4\u02BD',
                 ]

SinhalaVowelMap = [
                  '\uA984\uA9BC\u02BD'
                  ]

VowelSignMap =  [
                '\uA9B4',
                '\uA9B6',
                '\uA9B7',
                '\uA9B8',
                '\uA9B9',
                '\uA9BD',
                '\uA9C0\uA989\uA9B4',
                '\uA9C0\uA98A',
                '\uA9C0\uA98B',
                '\uA9BA',
                '\uA9BB',
                '\uA9BA\uA9B4',
                '\uA9BB\uA9B4',
                ]

SouthVowelSignMap = [
                    '\uA9BA\u02BD',
                    '\uA9BA\uA9B4\u02BD',
                    ]

ModernVowelSignMap =[
                    '\uA9BC',
                    '\uA9B4\u02BD']

SinhalaVowelSignMap = [
                      '\uA9BC\u02BD'
                      ]

AyogavahaMap = [
               '\uA980',
               '\uA981',
               '\uA983'
               ]

ViramaMap =  [
             '\uA9C0'
             ]

ConsonantMap =  [
                '\uA98F',
                '\uA991',
                '\uA992',
                '\uA993',
                '\uA994',

                '\uA995',
                '\uA996',
                '\uA997',
                '\uA999',
                '\uA99A',

                '\uA99B',
                '\uA99C',
                '\uA99D',
                '\uA99E',
                '\uA99F',

                '\uA9A0',
                '\uA9A1',
                '\uA9A2',
                '\uA9A3',
                '\uA9A4',

                '\uA9A5',
                '\uA9A6',
                '\uA9A7',
                '\uA9A8',
                '\uA9A9',

                '\uA9AA',
                '\uA9AB',
                '\uA9AD',
                '\uA9AE',

                '\uA9AF',
                '\uA9B0',
                '\uA9B1',
                '\uA9B2'
                ]

SouthConsonantMap = [
                    '\uA9AD\uA9B3',
                    '\uA9B0\uA9B3',
                    '\uA9AB\uA9B3',
                    '\uA9A4\uA9B3'
                    ]

NuktaConsonantMap =  [
                     '\uA98F\uA9B3',
                     '\uA991\uA9B3',
                     '\uA992\uA9B3',
                     '\uA997\uA9B3',
                     '\uA99D\uA9B3',
                     '\uA99E\uA9B3',
                     '\uA9A6\uA9B3',
                     '\uA9AA\uA9B3'
                     ]

SinhalaConsonantMap =[
                     '\uA980\uA992\u02BD',
                     '\uA980\uA997\u02BD',
                     '\uA980\uA99D\u02BD',
                     '\uA980\uA9A2\u02BD',
                     '\uA980\uA9A7\u02BD',
                      ]

NuktaMap = [
           '\uA9B3'
           ]

OmMap = [
        '\uA98E\uA980'
        ]

SignMap =[
         '\u0027',
         '\uA9C8',
         '\uA9C9'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']


NumeralMap = [
             '\uA9D0',
             '\uA9D1',
             '\uA9D2',
             '\uA9D3',
             '\uA9D4',
             '\uA9D5',
             '\uA9D6',
             '\uA9D7',
             '\uA9D8',
             '\uA9D9',
             ]

==> aksharamukha-2.0.2.tar.gz: aksharamukha-2.0.2/aksharamukha/ScriptMap/EastIndic/Javanese.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\uA984',
            '\uA984\uA9B4',
            '\uA986',
            '\uA987',
            '\uA988',
            '\uA988\uA9B4',
            '\uA989',
            '\uA989\uA9B4',
            '\uA98A',
            '\uA98B',
            '\uA98C',
            '\uA98D',
            '\uA98E',
            '\uA98E\uA9B4',
            ]

SouthVowelMap = [
                '\uA98C\u02BD',
                '\uA98E\u02BD',
                ]

ModernVowelMap = [
                 '\uA984\uA9BC',
                 '\uA984\uA9B4\u02BD',
                 ]

SinhalaVowelMap = [
                  '\uA984\uA9BC\uA9B4'
                  ]

VowelSignMap =  [
                '\uA9B4',
                '\uA9B6',
                '\uA9B7',
                '\uA9B8',
                '\uA9B9',
                '\uA9BD',
                '\uA9C0\uA989\uA9B4',
                '\uA9C0\uA98A',
                '\uA9C0\uA98B',
                '\uA9BA',
                '\uA9BB',
                '\uA9BA\uA9B4',
                '\uA9BB\uA9B4',
                ]

SouthVowelSignMap = [
                    '\uA9BA\u02BD',
                    '\uA9BA\uA9B4\u02BD',
                    ]

ModernVowelSignMap =[
                    '\uA9BC',
                    '\uA9B4\u02BD']

SinhalaVowelSignMap = [
                      '\uA9BC\uA9B4'
                      ]

AyogavahaMap = [
               '\uA980',
               '\uA981',
               '\uA983'
               ]

ViramaMap =  [
             '\uA9C0'
             ]

ConsonantMap =  [
                '\uA98F',
                '\uA991',
                '\uA992',
                '\uA993',
                '\uA994',

                '\uA995',
                '\uA996',
                '\uA997',
                '\uA999',
                '\uA99A',

                '\uA99B',
                '\uA99C',
                '\uA99D',
                '\uA99E',
                '\uA99F',

                '\uA9A0',
                '\uA9A1',
                '\uA9A2',
                '\uA9A3',
                '\uA9A4',

                '\uA9A5',
                '\uA9A6',
                '\uA9A7',
                '\uA9A8',
                '\uA9A9',

                '\uA9AA',
                '\uA9AB',
                '\uA9AD',
                '\uA9AE',

                '\uA9AF',
                '\uA9B0',
                '\uA9B1',
                '\uA9B2'
                ]

SouthConsonantMap = [
                    '\uA9AD\uA9B3',
                    '\uA9B0\uA9B3',
                    '\uA9AB\uA9B3',
                    '\uA9A4\uA9B3'
                    ]

NuktaConsonantMap =  [
                     '\uA98F\uA9B3',
                     '\uA991\uA9B3',
                     '\uA992\uA9B3',
                     '\uA997\uA9B3',
                     '\uA99D\uA9B3',
                     '\uA99E\uA9B3',
                     '\uA9A6\uA9B3',
                     '\uA9AA\uA9B3'
                     ]

SinhalaConsonantMap =[
                     '\uA980\uA992\u02BD',
                     '\uA980\uA997\u02BD',
                     '\uA980\uA99D\u02BD',
                     '\uA980\uA9A2\u02BD',
                     '\uA980\uA9A7\u02BD',
                      ]

NuktaMap = [
           '\uA9B3'
           ]

OmMap = [
        '\uA98E\uA980'
        ]

SignMap =[
         '\u0027',
         '\uA9C8',
         '\uA9C9'
         ]

Aytham =[AyogavahaMap[2]+'\u02BD']


NumeralMap = [
             '\uA9D0',
             '\uA9D1',
             '\uA9D2',
             '\uA9D3',
             '\uA9D4',
             '\uA9D5',
             '\uA9D6',
             '\uA9D7',
             '\uA9D8',
             '\uA9D9',
             ]
